Crate minigrep_crate
minigrep_
crate
0.1.0
All Items
Crate Items
Structs
Functions
Crate
minigrep_
crate
Structs

Config
Functions

run
search
Get the lines of the string that contain the given query
search_
case_
insensitive
Get the case insensitive lines of the string that contain the given query